Enum ServerVtxoPolicy

pub enum ServerVtxoPolicy {
    User(VtxoPolicy),
    Checkpoint(CheckpointVtxoPolicy),
    Expiry(ExpiryVtxoPolicy),
    HarkLeaf(HarkLeafVtxoPolicy),
    HarkForfeit(HarkForfeitVtxoPolicy),
}
Server-internal VTXO policy.

This is a superset of VtxoPolicy used by the server for internal tracking. Includes policies without user public keys.

Variants



User(VtxoPolicy)

Wraps any user-facing policy.



Checkpoint(CheckpointVtxoPolicy)

A policy which returns all coins to the server after expiry.



Expiry(ExpiryVtxoPolicy)

Server-only policy where coins can only be swept by the server after expiry.



HarkLeaf(HarkLeafVtxoPolicy)

hArk leaf output policy (intermediate outputs spent by leaf txs).



HarkForfeit(HarkForfeitVtxoPolicy)

hArk forfeit tx output policy

Implementations

Source

impl ServerVtxoPolicy

pub fn new_checkpoint(user_pubkey: PublicKey) -> Self

pub fn new_expiry(internal_key: XOnlyPublicKey) -> Self

pub fn new_hark_leaf(user_pubkey: PublicKey, unlock_hash: UnlockHash) -> Self

pub fn new_hark_forfeit(user_pubkey: PublicKey, unlock_hash: UnlockHash) -> Self

pub fn policy_type(&self) -> VtxoPolicyKind

The policy type id.

pub fn is_arkoor_compatible(&self) -> bool

Whether a Vtxo with this output can be spent in an arkoor tx.

pub fn user_pubkey(&self) -> Option<PublicKey>

Returns the user pubkey if this policy has one.

pub fn taproot( &self, server_pubkey: PublicKey, exit_delta: BlockDelta, expiry_height: BlockHeight, ) -> TaprootSpendInfo

pub fn script_pubkey( &self, server_pubkey: PublicKey, exit_delta: BlockDelta, expiry_height: BlockHeight, ) -> ScriptBuf

pub fn clauses( &self, exit_delta: u16, expiry_height: BlockHeight, server_pubkey: PublicKey, ) -> Vec<VtxoClause>

pub fn is_user_policy(&self) -> bool

Check whether this is a user policy

pub fn into_user_policy(self) -> Option<VtxoPolicy>

Try to convert to a user policy if it is one