pub struct ExpiryVtxoPolicy {
pub internal_key: XOnlyPublicKey,
}Expand description
Server-only policy where coins can only be swept by the server after expiry.
Fields
internal_key: XOnlyPublicKeyImplementations
Sourceimpl ExpiryVtxoPolicy
impl ExpiryVtxoPolicy
Sourcepub fn new(internal_key: XOnlyPublicKey) -> Self
pub fn new(internal_key: XOnlyPublicKey) -> Self
Creates a new expiry policy with the given internal key.
Sourcepub fn server_sweeping_clause(
&self,
expiry_height: BlockHeight,
server_pubkey: PublicKey,
) -> TimelockSignClause
pub fn server_sweeping_clause( &self, expiry_height: BlockHeight, server_pubkey: PublicKey, ) -> TimelockSignClause
Allows Server to spend after expiry height.
pub fn clauses( &self, expiry_height: BlockHeight, server_pubkey: PublicKey, ) -> Vec<VtxoClause>
pub fn taproot( &self, server_pubkey: PublicKey, expiry_height: BlockHeight, ) -> TaprootSpendInfo