pub struct HarkForfeitVtxoPolicy {
pub user_pubkey: PublicKey,
pub unlock_hash: UnlockHash,
}Expand description
The server-only VTXO policy on hArk forfeit txs
This policy allows the server to claim the forfeited coins by revealing the hArk unlock preimage or allow the user to recover its money in case the server doesn’t.
Fields
user_pubkey: PublicKeyunlock_hash: UnlockHashImplementations
Sourceimpl HarkForfeitVtxoPolicy
impl HarkForfeitVtxoPolicy
Sourcepub fn server_claim_clause(&self, server_pubkey: PublicKey) -> HashSignClause
pub fn server_claim_clause(&self, server_pubkey: PublicKey) -> HashSignClause
Server claims the forfeit revealing the unlock preimage
Sourcepub fn user_exit_clause(&self, exit_delta: BlockDelta) -> DelayedSignClause
pub fn user_exit_clause(&self, exit_delta: BlockDelta) -> DelayedSignClause
If the server doesn’t reveal the preimage, the user can claim the funds
pub fn clauses( &self, exit_delta: BlockDelta, server_pubkey: PublicKey, ) -> Vec<VtxoClause>
pub fn taproot( &self, server_pubkey: PublicKey, exit_delta: BlockDelta, ) -> TaprootSpendInfo