pub struct HarkLeafVtxoPolicy {
pub user_pubkey: PublicKey,
pub unlock_hash: UnlockHash,
}Expand description
Policy for hArk leaf outputs (intermediate outputs spent by leaf txs).
These are the outputs that feed into the final leaf transactions in a signed VTXO tree. They are locked by:
- An expiry clause allowing the server to sweep after expiry
- An unlock clause requiring a preimage and a signature from user+server
The internal key is set to the MuSig of user’s VTXO key + server pubkey.
Fields
user_pubkey: PublicKeyunlock_hash: UnlockHashImplementations
Sourceimpl HarkLeafVtxoPolicy
impl HarkLeafVtxoPolicy
Sourcepub fn expiry_clause(
&self,
expiry_height: BlockHeight,
server_pubkey: PublicKey,
) -> TimelockSignClause
pub fn expiry_clause( &self, expiry_height: BlockHeight, server_pubkey: PublicKey, ) -> TimelockSignClause
Creates the expiry clause allowing the server to sweep after expiry.
Sourcepub fn unlock_clause(&self, server_pubkey: PublicKey) -> HashSignClause
pub fn unlock_clause(&self, server_pubkey: PublicKey) -> HashSignClause
Creates the unlock clause requiring a preimage and aggregate signature.
Sourcepub fn clauses(
&self,
expiry_height: BlockHeight,
server_pubkey: PublicKey,
) -> Vec<VtxoClause>
pub fn clauses( &self, expiry_height: BlockHeight, server_pubkey: PublicKey, ) -> Vec<VtxoClause>
Returns the clauses for this policy.
Sourcepub fn taproot(
&self,
server_pubkey: PublicKey,
expiry_height: BlockHeight,
) -> TaprootSpendInfo
pub fn taproot( &self, server_pubkey: PublicKey, expiry_height: BlockHeight, ) -> TaprootSpendInfo
Build the taproot spend info for this policy.